"""Acceleration-facing interfaces corresponding to MNPBEM mex integrations."""

from __future__ import annotations
from importlib.metadata import PackageNotFoundError, version

from .backend import has_acceleration_backend

__all__ = ["has_acceleration_backend", "__version__", "module_status"]

try:
    __version__ = version("mnpbem-mex")
except PackageNotFoundError:
    __version__ = "0.0.0"

def module_status() -> str:
    return "alpha"









"""Optional acceleration backend probes."""

from __future__ import annotations

import importlib.util


def has_acceleration_backend(module_name: str = "mnpbem_accel") -> bool:
    """Return True when an optional compiled acceleration backend is importable."""
    return importlib.util.find_spec(module_name) is not None
